==> piwigo-2.10.2.zip: piwigo/language/nl_NL/upgrade.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | This file is part of Piwigo.                                          |
// |                                                                       |
// | For copyright and license information, please view the COPYING.txt    |
// | file that was distributed with this source code.                      |
// +-----------------------------------------------------------------------+

$lang['Upgrade'] = 'Upgrade';
$lang['This page proposes to upgrade your database corresponding to your old version of Piwigo to the current version. The upgrade assistant thinks you are currently running a <strong>release %s</strong> (or equivalent).'] = 'Deze pagina stelt voor om je
huidige Piwigo-database te converteren naar de nieuwe versie. De upgrade-assistent denkt dat je momenteel gebruik maakt van <strong>release %s</strong> (of equivalent).';
$lang['Upgrade from version %s to %s'] = 'Upgrade van versie %s naar versie %s';
$lang['Statistics'] = 'Statistieken';
$lang['total upgrade time'] = 'totale upgrade tijd';
$lang['total SQL time'] = 'totale SQL tijd';
$lang['SQL queries'] = 'SQL queries';
$lang['Upgrade informations'] = 'Upgrade informatie';
$lang['Perform a maintenance check in [Administration>Tools>Maintenance] if you encounter any problem.'] = 'Voer een onderhoudscontrole uit [Beheer>Hulpmiddelen>Onderhoud] indien je problemen ondervindt.';
$lang['As a precaution, following plugins have been deactivated. You must check for plugins upgrade before reactiving them:'] = 'Als voorzorgsmaatregel zijn de volgende plugins gedeactiveerd. Voordat je ze reactiveert moet je deze plugins op upgrades controleren:';
$lang['Only administrator can run upgrade: please sign in below.'] = 'Alleen een beheerder kan een upgrade uitvoeren: hieronder kun je inloggen.';
$lang['You do not have access rights to run upgrade'] = 'Je bent niet bevoegd om een upgrade uit te voeren';
$lang['All sub-albums of private albums become private'] = 'Alle sub-albums van privé albums worden privé';
$lang['User permissions and group permissions have been erased'] = 'Gebruikers- en groepsrechten zijn verwijderd';
$lang['Only thumbnails prefix and webmaster mail address have been saved from previous configuration'] = 'Alleen het voorvoegsel (prefix) van de klikplaatjes en het e-mail-adres van de webbeheerder zijn bewaard gebleven van de vorige configuratie';
$lang['In <i>%s</i>, before <b>?></b>, insert:'] = 'In <i>%s</i>, voor <b>?></b>, voeg tussen:';
$lang['As a precaution, following themes have been deactivated. You must check for themes upgrade before reactiving them:'] = 'Als voorzorgsmaatregel zijn de volgende thema\'s gedeactiveerd. Controleer of er nieuwe versies van deze thema\'s bestaan, voordat je ze reactiveert:';
$lang['Discover what\'s new in Piwigo %s'] = 'Ontdek wat er nieuw is in Piwigo %s';

==> piwigo-12.2.0.zip: piwigo/language/nl_NL/upgrade.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | This file is part of Piwigo.                                          |
// |                                                                       |
// | For copyright and license information, please view the COPYING.txt    |
// | file that was distributed with this source code.                      |
// +-----------------------------------------------------------------------+

$lang['Upgrade'] = 'Upgrade';
$lang['This page proposes to upgrade your database corresponding to your old version of Piwigo to the current version. The upgrade assistant thinks you are currently running a <strong>release %s</strong> (or equivalent).'] = 'Deze pagina stelt voor om je
huidige Piwigo-database te converteren naar de nieuwe versie. De upgrade-assistent denkt dat je momenteel gebruik maakt van <strong>release %s</strong> (of equivalent).';
$lang['Upgrade from version %s to %s'] = 'Upgrade van versie %s naar versie %s';
$lang['Statistics'] = 'Statistieken';
$lang['total upgrade time'] = 'totale upgrade tijd';
$lang['total SQL time'] = 'totale SQL tijd';
$lang['SQL queries'] = 'SQL queries';
$lang['Upgrade informations'] = 'Upgrade informatie';
$lang['Perform a maintenance check in [Administration>Tools>Maintenance] if you encounter any problem.'] = 'Voer een onderhoudscontrole uit [Beheer>Hulpmiddelen>Onderhoud] indien je problemen ondervindt.';
$lang['As a precaution, following plugins have been deactivated. You must check for plugins upgrade before reactiving them:'] = 'Als voorzorgsmaatregel zijn de volgende plug-ins gedeactiveerd. Voordat je ze reactiveert moet je deze plug-ins op upgrades controleren:';
$lang['Only administrator can run upgrade: please sign in below.'] = 'Alleen een beheerder kan een upgrade uitvoeren: hieronder kun je inloggen.';
$lang['You do not have access rights to run upgrade'] = 'Je bent niet bevoegd om een upgrade uit te voeren';
$lang['All sub-albums of private albums become private'] = 'Alle sub-albums van privé albums worden privé';
$lang['User permissions and group permissions have been erased'] = 'Gebruikers- en groepsrechten zijn verwijderd';
$lang['Only thumbnails prefix and webmaster mail address have been saved from previous configuration'] = 'Alleen het voorvoegsel (prefix) van de klikplaatjes en het e-mail-adres van de webbeheerder zijn bewaard gebleven van de vorige configuratie';
$lang['In <i>%s</i>, before <b>?></b>, insert:'] = 'In <i>%s</i>, voor <b>?></b>, voeg tussen:';
$lang['As a precaution, following themes have been deactivated. You must check for themes upgrade before reactiving them:'] = 'Als voorzorgsmaatregel zijn de volgende thema\'s gedeactiveerd. Controleer of er nieuwe versies van deze thema\'s bestaan, voordat je ze reactiveert:';
$lang['Discover what\'s new in Piwigo %s'] = 'Ontdek wat er nieuw is in Piwigo %s';
